==> jaysonic-3.3.1.tgz: package/lib/client/tcp.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

var JsonRpcClientFactory = require(".");

var TcpClientProtocol = require("./protocol/tcp");
/**
 * Creates instance of TcpClientFactory
 *
 * @extends JsonRpcClientFactory
 */


var TcpClientFactory = /*#__PURE__*/function (_JsonRpcClientFactory) {
  _inherits(TcpClientFactory, _JsonRpcClientFactory);

  var _super = _createSuper(TcpClientFactory);

  function TcpClientFactory() {
    _classCallCheck(this, TcpClientFactory);

    return _super.apply(this, arguments);
  }

  _createClass(TcpClientFactory, [{
    key: "buildProtocol",
    value:
    /** @inheritdoc */
    function buildProtocol() {
      this.pcolInstance = new TcpClientProtocol(this, this.options.version, this.options.delimiter);
    }
    /** @inheritdoc */

  }, {
    key: "end",
    value: function end(cb) {
      this.pcolInstance.end(cb);
    }
    /** @inheritdoc */

  }, {
    key: "subscribe",
    value: function subscribe(method, cb) {
      this.on(method, cb);
    }
    /** @inheritdoc */

  }, {
    key: "unsubscribe",
    value: function unsubscribe(method, cb) {
      this.removeListener(method, cb);
    }
    /** @inheritdoc */

  }, {
    key: "unsubscribeAll",
    value: function unsubscribeAll(method) {
      this.removeAllListeners([method]);
    }
  }]);

  return TcpClientFactory;
}(JsonRpcClientFactory);

module.exports = TcpClientFactory;

==> jaysonic-3.5.1.tgz: package/lib/client/tcp.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

var JsonRpcClientFactory = require(".");

var TcpClientProtocol = require("./protocol/tcp");
/**
 * Creates instance of TcpClientFactory
 *
 * @extends JsonRpcClientFactory
 */


var TcpClientFactory = /*#__PURE__*/function (_JsonRpcClientFactory) {
  _inherits(TcpClientFactory, _JsonRpcClientFactory);

  var _super = _createSuper(TcpClientFactory);

  function TcpClientFactory(options) {
    var _this;

    _classCallCheck(this, TcpClientFactory);

    _this = _super.call(this, options);
    _this.protocol = TcpClientProtocol;
    return _this;
  }
  /** @inheritdoc */


  _createClass(TcpClientFactory, [{
    key: "buildProtocol",
    value: function buildProtocol() {
      this.pcolInstance = new this.protocol(this, this.options.version, this.options.delimiter);
    }
    /** @inheritdoc */

  }, {
    key: "end",
    value: function end(cb) {
      this.pcolInstance.end(cb);
    }
    /** @inheritdoc */

  }, {
    key: "subscribe",
    value: function subscribe(method, cb) {
      this.on(method, cb);
    }
    /** @inheritdoc */

  }, {
    key: "unsubscribe",
    value: function unsubscribe(method, cb) {
      this.removeListener(method, cb);
    }
    /** @inheritdoc */

  }, {
    key: "unsubscribeAll",
    value: function unsubscribeAll(method) {
      this.removeAllListeners([method]);
    }
  }]);

  return TcpClientFactory;
}(JsonRpcClientFactory);

module.exports = TcpClientFactory;
